Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1682)

Unified Diff: pkg/analysis_server/lib/src/services/completion/imported_computer.dart

Issue 1060713005: rename completion computer to contributor (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: merge Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/services/completion/imported_computer.dart
diff --git a/pkg/analysis_server/lib/src/services/completion/imported_computer.dart b/pkg/analysis_server/lib/src/services/completion/imported_computer.dart
index ae924c054f6c731b0223ad11566f09ee6a7900e4..17594f83d69abc4b25446f1328db2d543ee43f20 100644
--- a/pkg/analysis_server/lib/src/services/completion/imported_computer.dart
+++ b/pkg/analysis_server/lib/src/services/completion/imported_computer.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library services.completion.computer.dart.toplevel;
+library services.completion.contributor.dart.toplevel;
import 'dart:async';
import 'dart:collection';
@@ -17,15 +17,15 @@ import 'package:analyzer/src/generated/ast.dart';
import 'package:analyzer/src/generated/element.dart';
/**
* A computer for calculating imported class and top level variable
* `completion.getSuggestions` request results.
*/
-class ImportedComputer extends DartCompletionComputer {
+class ImportedReferenceContributor extends DartCompletionContributor {
bool shouldWaitForLowPrioritySuggestions;
bool suggestionsComputed;
_ImportedSuggestionBuilder builder;
- ImportedComputer({this.shouldWaitForLowPrioritySuggestions: false});
+ ImportedReferenceContributor({this.shouldWaitForLowPrioritySuggestions: false});
@override
bool computeFast(DartCompletionRequest request) {
@@ -190,7 +190,7 @@ class _ImportedSuggestionBuilder extends ElementSuggestionBuilder
// and include any inherited imported members
List<String> inheritedTypes = new List<String>();
visitInheritedTypes(classDecl, (_) {
// local declarations are handled by the local computer
}, (String typeName) {
inheritedTypes.add(typeName);
});
@@ -17,15 +17,15 @@ import 'package:analyzer/src/generated/ast.dart';
import 'package:analyzer/src/generated/element.dart';
/**
- * A computer for calculating imported class and top level variable
+ * A contributor for calculating imported class and top level variable
* `completion.getSuggestions` request results.
*/
@@ -190,7 +190,7 @@ class _ImportedSuggestionBuilder extends ElementSuggestionBuilder
List<String> inheritedTypes = new List<String>();
visitInheritedTypes(classDecl, (_) {
- // local declarations are handled by the local computer
+ // local declarations are handled by the local reference contributor
}, (String typeName) {
inheritedTypes.add(typeName);

Powered by Google App Engine
This is Rietveld 408576698